#[repr(C)]pub struct FvmfileCommand {
pub cmd: u32,
pub cmdsize: u32,
pub name: u32,
pub header_addr: u32,
}Expand description
The fvmfile_command contains a reference to a file to be loaded at the specified virtual address. (Presently, this command is reserved for internal use. The kernel ignores this command when loading a program into memory).
Fields
cmd: u32LC_FVMFILE
cmdsize: u32includes pathname string
name: u32files pathname
header_addr: u32files virtual address